#
# spec file for package libbluray
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2011 Dominique Leuenberger, Amsterdam, The Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 2
Name:           libbluray
Version:        1.3.4
Release:        2.1
Summary:        Library to access Blu-Ray disk
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            https://www.videolan.org/developers/libbluray.html
Source0:        https://download.videolan.org/pub/videolan/%{name}/%{version}/%{name}-%{version}.tar.bz2
Source99:       baselibs.conf
Patch0:         libbluray-pkgconfig.patch
Patch1:         libbluray-java18plus.patch
BuildRequires:  ant
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  java-devel >= 1.8
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.6

%description
This library is written for the purpose of playing Blu-ray movies. It is
intended for software that want to support Blu-ray playback (such as VLC and
MPlayer). We, the authors of this library, do not condone nor endorse piracy.

%package -n libbluray%{sover}
Summary:        Library to access Blu-Ray disk
Group:          System/Libraries

%description -n libbluray%{sover}
This library is written for the purpose of playing Blu-ray movies. It is
intended for software that want to support Blu-ray playback (such as VLC and
MPlayer). We, the authors of this library, do not condone nor endorse piracy.

%package tools
Summary:        Library to access Blu-Ray disk - Utilities
Group:          Productivity/Multimedia/Other

%description tools
This library is written for the purpose of playing Blu-ray movies. It is
intended for software that want to support Blu-ray playback (such as VLC and
MPlayer). We, the authors of this library, do not condone nor endorse piracy.

%package devel
Summary:        Library to access Blu-Ray disks - Development files
Group:          Development/Languages/C and C++
Requires:       libbluray%{sover} = %{version}

%description devel
This library is written for the purpose of playing Blu-ray movies. It is
intended for software that want to support Blu-ray playback (such as VLC and
MPlayer). We, the authors of this library, do not condone nor endorse piracy.

%package bdj
Summary:        Library to access Blu-Ray disk - BD-J support
Group:          Development/Libraries/Java
Requires:       jpackage-utils
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
Requires:       java >= 9
%else
Requires:       java >= 1.8
%endif
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description bdj
This library is written for the purpose of playing Blu-ray movies. It is
intended for software that want to support Blu-ray playback (such as VLC and
MPlayer). We, the authors of this library, do not condone nor endorse piracy.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure \
    --disable-static \
    --enable-bdjava \
    --enable-udf
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libbluray%{sover} -p /sbin/ldconfig
%postun -n libbluray%{sover} -p /sbin/ldconfig

%files tools
%{_bindir}/bd_info
%{_bindir}/bd_list_titles
%{_bindir}/bd_splice

%files -n libbluray%{sover}
%license COPYING
%{_libdir}/libbluray.so.*

%files devel
%{_includedir}/%{name}/
%{_libdir}/libbluray.so
%{_libdir}/pkgconfig/libbluray.pc

%files bdj
%{_javadir}/libbluray-awt-j2se-%{version}.jar
%{_javadir}/libbluray-j2se-%{version}.jar

%changelog
* Mon Oct 30 2023 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * libbluray-java18plus.patch
    + allow building with JDK 18 and newer (using source/target
    levels 8)
    + fixes build with the new OpenJDK 21 LTSS
* Fri Dec  2 2022 Dirk Müller <dmueller@suse.com>
- update to 1.3.4:
  * Improve API documentation.
  * Improve JVM probing.
  * Improve support for FreeBSD and Solaris.
  * Improve .jar file search.
  * Add configure option to build without external libudfread.
* Thu Sep 29 2022 Dirk Müller <dmueller@suse.com>
- update to 1.3.3:
  * Initial support for Java 18.
  * Add support for OpenBSD operating system.
  * Improve support for FreeBSD, NetBSD and DragonFlyBSD
  * Improve Java 17 support.
* Mon Aug  8 2022 Dirk Müller <dmueller@suse.com>
- update to 1.3.2:
  - Fix build/run failure after Oracle Java CPU for April 2022
- drop patch libbluray-April2022CPU.patch (upstream)
* Thu Apr 21 2022 Fridrich Strba <fstrba@suse.com>
- Removed patch:
  * libbluray-java9.patch
    + Does not have any effect in the current build
- Added patch:
  * libbluray-April2022CPU.patch
    + implement the new java.io.FileSystem.isInvalid method
    that entered all supported java versions with April 2022 CPU
* Sat Apr  9 2022 Dirk Müller <dmueller@suse.com>
- update to 1.3.1:
  * Add support for Java 13 ... 16.
  * Improve JVM probing in Windows.
  * Fix playback issues with some discs when using recent libbdplus.
  * Fix loading dlopen'd libraries on OpenBSD.
* Tue May  4 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.3.0:
  + Add bd_event_name().
  + Add return value to bd_refcnt_inc().
  + Add cache for parsed clpi file data.
  + Add player setting for JRE location (JAVA_HOME).
  + Improve FreeBSD BD-J support.
  + Improve portability.
  + Improve JVM and .jar file probing.
  + Fix leak.
- Drop libbluray-jvm_dir.patch
* Thu Nov  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.2.1:
  + Add initial support for .fmts files.
  + Improve missing/broken playlist handling.
  + Improve UHD metadata support.
  + Improve BD-J compability.
  + Improve error resilience and stability.
  + Fix long delay in "Evangelion, You are (not) alone" menu.
  + Fix JVM bootstrap issues with some Java 9 versions.
  + Fix sign extended bytes when reading single bytes in BDJ.
  + Fix creating organization and disc specific BD-J BUDA
    directories.
  + Use external libudfread when available.
  + Rename list_titles to bd_list_titles and add it to installed
    programs.
* Mon Apr 27 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.2.0
  * Add functions to list and read BD-ROM files.
  * Add support for separate key pressed / typed / released user
    input events.
  * Add support for AWT mouse events (BD-J).
  * Fix build with OpenJDK 12 / 13.
* Sat Aug  3 2019 enzokiel@kabelmail.de
- Update to version 1.1.2:
  + Add libxml version to pkg-config Requires.private.
  + Improve support for NetBSD operating system.
  + Improve BD-J compability.
  + Improve Java 8+ compability.
  + Fix main playlist caching in Windows.
  + Fix mark triggering when multiple marks are passed during
    single read().
  + Fix seek bar pop-up at chapter boundary with some discs.
  + Fix reading resources indirectly from mounted .jar file.
- Fixed libbluray-java9.patch.
- Enable build against java-devel >= 10.
* Mon Apr  8 2019 enzokiel@kabelmail.de
- Update to version 1.1.1:
  + Enable playback without menus when index.bdmv is missing.
  + Improve error resilience and stability.
  + Improve BD-J compability.
  + Fix loading libraries on MacOS / hardened runtime.
  + Fix resetting user-selected streams when playing without menus.
  + Fix stack overflow when using Java9+ with debugger connection.
  + Fix polygon-based BD-J graphics primitives.
  + Fix loading libmmbd in Windows 64-bit.
  + Fix loading classes with Windows Java 8.
  + Fix build with Java 1.6.
  + Fix pkg-config Libs.private.
- Fixed libbluray-pkgconfig.patch.
* Thu Mar 21 2019 olaf@aepfle.de
- Remove unused dependencies from pkgconfig(libbluray)
  Our pkg is dynamically linked, so Libs.private is not needed
  Nothing in the exported header files needs paths from
  Requires.private
  libbluray-pkgconfig.patch
* Fri Feb 15 2019 enzokiel@kabelmail.de
- Update to version 1.1.0:
  + Add initial support for OpenJDK 11.
  + Add initial support for UHD disc BD-J menus.
  + Add support for compiling .jar file with Java 9+ compiler.
  + Move AWT classes to separate .jar file.
  + Update libudfread submodule repository URL.
  + Improve main title selection.
  + Improve error resilience and stability.
  + Improve BD-J compability.
  + Fix playback of some broken BD-J discs.
  + Fix playback of discs without normal titles (only TopMenu /
    FirstPlay title).
* Tue Dec 19 2017 fstrba@suse.com
- Modified patch:
  * libbluray-java9.patch
    + Some change in hunks integrating upstream fixes that were
    partially different from ours.
* Tue Dec 19 2017 fstrba@suse.com
- BuildConflict with jdk10 or higher, since some removal of
  deprecated SecurityManager functions makes BD-J not buildable
  with jdk10
* Tue Dec  5 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.0.2:
  + Add initial support for UHD BluRay discs (without BD-J menus).
  + Detect JRE (from the Java Applet plugin) on MacOS.
  + Improve error resilience and stability.
  + Improve libmmbd support.
  + Fix static build dependencies in pkgconfig file.
  + Fix creation of cache (sub-)directories on windows platforms.
  + Fix BD-J temporary storage when persistent storage is disabled.
  + Fix leaks.
- At least java-devel >= 1.8 ist required for build.
* Mon Oct 30 2017 fstrba@suse.com
- Added patch:
  * libbluray-java9.patch
    + Fix build with jdk9
    + Due to incompatible changes in jdk9, the same code cannot be
    built with jdk9 and jdk <= 1.8
    + Only apply on systems that hava jdk9
* Sun Sep 10 2017 dimstar@opensuse.org
- BuildConflict with java-devel >= 1.9. Java 8 is the last to
  support source_version 1.5.
* Thu Jun 15 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.0.1:
  + Add possibility to check whether BD-J is functional without
    opening a disc.
  + Improve main title selection.
  + Improve error resilience and stability.
  + Fix Windows dll loading.
  + Fix JAVA_HOME environment variable handling in Windows.
  + Fix build issues when CPPFLAGS is given in make command line.
  + Fix MSVC build issues.
  + Remove --disable-bdjava and --disable-udf configure options.
- Fixed patch libbluray-jvm_dir.patch.
* Fri Mar  3 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.0.0:
  + Add support for Java VM (BD-J) on MacOS.
  + Add clip_id to BLURAY_CLIP_INFO.
  + Add a suitable JVM path for Fedora/RHEL and clones.
  + Add support for AVCHD 8.3 filenames.
  + Add player setting for disabling persistent storage.
  + Add bd_set_rate().
  + Add playback time position to BD_EVENT_SEEK.
  + Add BD_VK_ROOT_MENU handling.
  + Add support for heavily fragmented 3D .m2ts files.
  + Improve Win32 dll loading security.
  + Improve playback resume position accuracy.
  + Improve error resilience and stability.
  + Fix using libmmbd with unmounted discs.
  + Fix leaks.
  + Delay BD-J overlay opening until something visible has been
    drawn.
  + Close BD-J overlay when window is not visible.
  + Use temporary storage when cache or persistent root location is
    unknown.
- Fixed patch libbluray-jvm_dir.patch.
- Changed soname version to 2.
* Mon Feb 13 2017 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use.
  Fix RPM groups.
* Sun Feb 12 2017 pascal.bleser@opensuse.org
- drop patch A02-expopse-clip_id.patch as Handbrake seems to be the only
  package that needs it, to avoid binary runtime incompatibilities with
  libbluray packages that would stem from other repositories
* Thu Feb  2 2017 pascal.bleser@opensuse.org
- add patch to expose clip_id (as applied by Debian), which is
  necessary to build packages that depend on it (such as Handbrake)
  * A02-expose-clip_id.patch
* Tue Aug 16 2016 tchvatal@suse.com
- Drop libbluray-autotools.patch as it has no real benefit and if
  something should be upstreamed
* Thu May 19 2016 tchvatal@suse.com
- Fix download url to not fail on network error
* Tue May 17 2016 joerg.lorenzen@ki.tng.de
- Update to version 0.9.3:
  + Add bd_open_files(). This function deprecates old global file
    system hooks.
  + Add flag for on-disc menu support to DISC_INFO.
  + Add configure argument to disable building of JAR file.
  + Add missing player settings enums.
  + Update linux Java search path list and preferred JVM.
  + Enable UDF support by default.
  + Split developer tools from examples.
  + Improve BDJ_EVENT_CHAPTER triggering.
  + Improve main title detection.
  + Improve error resilience.
  + Improve BD-J compability.
  + Improve detecting of working aacs implementation.
  + Improve libmmbd support.
  + Fix BD-J media player stop().
  + Fix restoring playback rate with some BD-J discs.
  + Fix restoring suspended playback time position.
  + Fix current chapter lookup.
  + Fix lost key focus with multi-HScene discs.
  + Fix playback of discs without Top Menu title.
  + Fix caching of some BD-J files from UDF filesystem.
  + Fix stopping playback from HDMV menus.
  + Fix possible errors in win32 .iso image reading.
  + Fix undefined values in DISC_INFO.
  + Fix memory leaks.
- Fixed patch libbluray-jvm_dir.patch.
* Thu Dec  3 2015 joerg.lorenzen@ki.tng.de
- Update to version 0.9.2:
  + Add primary audio stream to bd_select_stream().
  + Improve error resilience.
  + Fix Java 8 compability issues.
  + Fix Android build.
  + Fix SecurityException in AWTAutoShutdown.
  + Fix BD-J check when install path in Windows contains
    non-ASCII chars.
  + Fix jvm.dll loading in Windows ($JAVA_HOME/bin should be in
    dll load path).
  + Fix class translating in recent Java 8 versions.
- Fixed patches libbluray-autotools.patch and libbluray-jvm_dir.patch.
* Wed Nov  4 2015 idonmez@suse.com
- Update to version 0.9.1
  + Improved BD-J security.
  + Improved error resilience.
  + Improved seeking (avoid skipping PAT/PMT/PCR).
  + Fix UO mask check when bd_play_title() is used for Top Menu.
  + Fix re-starting of title bound Xlets when title changes.
  + Fix loading classes with invalid debug info.
* Mon Oct  5 2015 joerg.lorenzen@ki.tng.de
- Update to version 0.9.0:
  + Add functions to read files from VFS.
  + Improved error resilience.
  + Improved BD-J compability.
  + Fix Xlet-initiated font caching.
  + Fix return value when setting BLURAY_PLAYER_SETTING_DECODE_PG.
  + Fix build with C++ compiler
* Mon Aug 10 2015 olaf@aepfle.de
- Fix build in SLE_11
* Fri May 22 2015 joerg.lorenzen@ki.tng.de
- Update to version 0.8.1:
  + Notify application when UO mask changes.
  + Improved error resilience.
  + Improved BD-J compability.
  + Fix crash after bd_open(NULL).
  + Fix compability problem with libbdplus.
  + Fix memory leak in UDF filesystem parser.
  + Fix crash in freetype.
* Thu Apr 30 2015 joerg.lorenzen@ki.tng.de
- Update to version 0.8.0:
  + Add security checks to BD-J.
  + Add support for UDF image files and unmounted discs.
  + Add UDF volume identifier to DISC_INFO.
  + Add bd_init(), bd_open_disc() and bd_open_stream().
  + Add /usr/share/libbluray/lib/ to .jar file search paths.
  + Add BD_EVENT_PLAYLIST_STOP (playlist playback is interrupted).
  + Accept directory name (without .jar file name) in LIBBLURAY_CP.
  + Improved error resilence.
  + Improve BD-J compability.
  + Fix Java 8u40 compability.
  + Fix infinite loop with some broken HDMV menus.
- Fixed patches libbluray-autotools.patch and libbluray-jvm_dir.patch.
- Build with UDF support.
* Fri Mar  6 2015 tchvatal@suse.com
- Put the configure args each on its own line
* Tue Feb 10 2015 tchvatal@suse.com
- Use proper homepage.
* Tue Jan 27 2015 joerg.lorenzen@ki.tng.de
- Update to version 0.7.0:
  + Add player setting for BD-J persistent storage and cache paths.
  + Add support for system fonts. BD-J fonts in jre/lib/fonts/
    are not required anymore.
  + Add BD-J organization ID and disc ID to BLURAY_DISC_INFO.
  + Release still mode when BD-J terminates.
  + Implement BD-J caching.
  + Improve BD-J compability.
  + Java 8 compability fixes.
  + Fix storage size for bdjo object reference in BLURAY_DISC_INFO.
  + Fix BD-J on-disc font usage.
  + Fix animations in some BD-J menus.
  + Fix BD-J storage path charset issues in Windows.
* Fri Dec 19 2014 joerg.lorenzen@ki.tng.de
- Added patch libbluray-jvm_dir.patch to set the correct path to
  java lib because variable JAVA_HOME on openSUSE is defined
  as '/usr/<LIB>/jvm/jre' by update-alternatives.
* Thu Dec 18 2014 joerg.lorenzen@ki.tng.de
- Enable BD-J support.
* Wed Dec 17 2014 joerg.lorenzen@ki.tng.de
- Update to version 0.6.2:
  + Fix possible subtitle corruption after seek.
  + Fix some main path embedded HDMV menus.
  + Fix reading outside of source image in BD-J drawImage().
  + Fix missing BD_EVENT_ERROR when BD-J is not supported.
  + Several stability and code quality fixes.
- Version 0.6.1:
  + Fix stream position when seamless angle change point is at
    clip boundary.
  + Fix Mac OS X jni compilation
  + Fix bd_seek() jumping outside of clip/playlist.
  + Fix crash when stream selection is changed after playlist end.
  + Fix J2ME build.
  + Fix seamless angle change.
  + Fix freetype2 resource leaks on shutdown.
  + Improve duplicate playlist detection.
- Version 0.6.0:
  + Improved BD-J support (Most BD-J discs are correctly played).
  + Mark BD-J titles supported in BLURAY_DISC_INFO if BD-J is
    functional.
  + Install .jar files to datadir (/usr/share/java/) instead of
    libdir.
  + Added version number to .jar file names.
  + Added JNI headers for BD-J (cross) compilation.
  + Added HDMV/BD-J title information to BLURAY_DISC_INFO.
  + Added disc application info to BLURAY_DISC_INFO.
  + Added bd_set_rate().
  + Added color keys (RED, GREEN, YELLOW, BLUE).
  + Improved error resilence.
  + Fix build without libxml.
- Version 0.5.0:
  + Portability fixes.
  + Build system updates.
  + Improved BD-J support (still alpha).
  + Improved updating of application-allocated ARGB frame buffer.
  + Get JRE library location from registry (Windows).
  + Added bd_get_main_title().
  + Added BD_EVENT_ERROR when title playback fails.
  + Added BD-J flags to disc info.
  + Added support for user timeout in HDMV menus.
  + Added cropping of RLE images. Cropping values in overlay are
    now always 0.
  + Added support for LIBAACS_PATH and LIBBDPLUS_PATH environment
    variables.
  + Added timestamp based m2ts stream filtering.
- Removed patch use-recommended-freetype-include.patch,
  fixed upstream.
* Wed Jan  1 2014 crrodriguez@opensuse.org
- Select the C standard to be used with autoconf macros
  instead of passing std=c99.
- Correct CPPFLAGS and CFLAGS
- Ensure config.h is always included, in 32 bit OS the library
  was using both fopen() and fopen64() this will cause
  problems with largefiles due to _FILE_OFFSET_BITS=64 beign
  used inconsistenly.
- Patch name : libbluray-autotools.patch
* Wed Dec 11 2013 hrvoje.senjan@gmail.com
- Added use-recommended-freetype-include.patch -- Freetype upstream
  recommends using their macros together with ft2build include.
  Positive sideeffect is that this patch makes it build with both
  freetype2 2.5.1, and older version
* Fri Oct  4 2013 zaitor@opensuse.org
- Update to version 0.4.0:
  + Fixed slide shows: always cut reads at clip end boundary.
  + Fixed logging with non-default mask.
  + Fixed buffer overflow in bd_psr_unregister_cb().
  + Fixed IG background when button image position changes.
  + Fixed BD-J tearing issues.
  + Changed default PhoneME library name in Windows (cvm -> cvmi).
  + Initialize default player region code to B.
  + Improved BD-J support (still alpha).
  + Improved language-based stream autoselection.
  + Added missing Java files to distribution package.
  + Added support for multi-clip sub paths.
  + Added bd_select_stream().
  + Added menu page effects.
  + Added button animations.
  + Added initial support for BluRay Text Subtitles.
  + Added bd_read_clpi(): use only public API in clpi_dump.
  + Added reference-counted RLE images.
- Add pkgconfig(freetype2) BuildRequires, new dependency.
* Tue May  7 2013 dimstar@opensuse.org
- Update to version 0.3.0:
  + Build fixes.
  + Fixed stopping playback from pop-up menu.
  + Fixed multithreading issues in API.
  + Fixed initial setting for player profile.
  + Fixed stack corruption with long log strings.
  + Improved configure script.
  + Improved Visual Studio support.
  + Improved BD-J support (still alpha).
  + Allow changing player version.
  + Added PG (subtitle) decoding and rendering support.
  + Added ARGB overlay interface for BD-J graphics.
  + Added events for discontinuity, idle state and 3D mode.
  + Added playmarks to BLURAY_TITLE_INFO.
  + added start time, in time and out time to BLURAY_CLIP_INFO.
  + added sub-path id to BLURAY_STREAM_INFO.
  + Added bd_seek_playitem().
  + Added bd_set_scr().
  + Added 3D extension data to raw clip info.
  + added 3D player settings.
  + Added cropping and palette update flag to BD_OVERLAY.
- Add  pkgconfig(libxml-2.0) BuildRequires: new dependency.
* Sat Sep 15 2012 dimstar@opensuse.org
- Update to version 0.2.3:
  + Default to stream 0 when language not found
  + Bug fixes
- Add tools subpackage, with the new command line utilities.
* Fri May 25 2012 dimstar@opensuse.org
- Update to version 0.2.2:
  + Fixed displaying of single-loop animated buttons when not using
    animations
  + Added events for pop-up menu availability and IG menu status
  + Fixed resuming to interactive title
  + Use user filesystem handler with libaacs
  + Fixes to HDMV menu rendering
  + Optimized HDMV menu rendering
  + Support for sound effects in HDMV menus
  + Fixes to HDMV menu decoding
  + Distribute BD-J code
* Mon Jan  9 2012 vuntz@opensuse.org
- Add baselibs.conf, to build 32bit packages, as needed by gvfs.
* Sat Dec  3 2011 idoenmez@suse.de
- Fix soname version to 1
* Fri Dec  2 2011 dimstar@opensuse.org
- Update to version 0.2.1:
  + Make library version information visible to applications.
  + First released tarball.
- Remove automake BuildRequires: this is now a real release that
  was already bootstrapped.
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Nov 16 2011 dimstar@opensuse.org
- Initial package, version 0.1.99 (a git-snapshot)
